diff src/buffer.h @ 25654:4bf85d1d270b

(prompt_end_charpos): Replaces minibuffer_prompt_length.
author Gerd Moellmann <gerd@gnu.org>
date Sun, 12 Sep 1999 20:21:49 +0000
parents e98819a94512
children 34d057fe496f
line wrap: on
line diff
--- a/src/buffer.h	Sun Sep 12 20:21:48 1999 +0000
+++ b/src/buffer.h	Sun Sep 12 20:21:49 1999 +0000
@@ -546,9 +546,9 @@
     /* The name of this buffer.  */
     Lisp_Object name;
 
-    /* Length in characters of the prompt in a mini-buffer, or nil if
-       this buffer is not a mini-buffer.  */
-    Lisp_Object minibuffer_prompt_length;
+    /* Character position at the end of a mini-buffer prompt, or or
+       nil if this buffer is not a mini-buffer.  */
+    Lisp_Object prompt_end_charpos;
 
     /* The name of the file visited in this buffer, or nil.  */
     Lisp_Object filename;